==> webkit2gtk_2.23.3.orig.tar.xz: webkitgtk-2.23.3/Source/WebCore/Modules/webgpu/WebGPUSwapChain.cpp <==
/*
 * Copyright (C) 2018 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "WebGPUSwapChain.h"

#if ENABLE(WEBGPU)

#include "GPUTextureFormatEnum.h"

namespace WebCore {

WebGPUSwapChain::~WebGPUSwapChain() = default;

void WebGPUSwapChain::configure(Descriptor&& descriptor)
{
    if (descriptor.device)
        m_swapChain->setDevice(descriptor.device->device());

    m_swapChain->setFormat(descriptor.format);

    reshape(descriptor.width, descriptor.height);
}

RefPtr<WebGPUTexture> WebGPUSwapChain::getNextTexture()
{
    return WebGPUTexture::create(m_swapChain->getNextTexture());
}

void WebGPUSwapChain::present()
{
    markLayerComposited();
}

void WebGPUSwapChain::reshape(int width, int height)
{
    m_swapChain->reshape(width, height);
}

void WebGPUSwapChain::markLayerComposited()
{
    m_swapChain->present();
}

} // namespace WebCore

#endif // ENABLE(WEBGPU)

==> webkit2gtk_2.30.3.orig.tar.xz: webkitgtk-2.30.3/Source/WebCore/Modules/webgpu/WebGPUSwapChain.cpp <==
/*
 * Copyright (C) 2018 Apple Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE INC. AND ITS CONTRIBUTORS ``AS IS''
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO,
 * THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL APPLE INC. OR ITS CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "config.h"
#include "WebGPUSwapChain.h"

#if ENABLE(WEBGPU)

#include "Logging.h"
#include "WebGPUSwapChainDescriptor.h"

namespace WebCore {

Ref<WebGPUSwapChain> WebGPUSwapChain::create(RefPtr<GPUSwapChain>&& swapChain)
{
    return adoptRef(*new WebGPUSwapChain(WTFMove(swapChain)));
}

WebGPUSwapChain::WebGPUSwapChain(RefPtr<GPUSwapChain>&& swapChain)
    : m_swapChain(WTFMove(swapChain))
{
}

Ref<WebGPUTexture> WebGPUSwapChain::getCurrentTexture()
{
    if (!m_swapChain) {
        LOG(WebGPU, "GPUSwapChain::getCurrentTexture(): Invalid operation!");
        return WebGPUTexture::create(nullptr);
    }
    m_currentTexture = WebGPUTexture::create(m_swapChain->tryGetCurrentTexture());
    return makeRef(*m_currentTexture);
}

void WebGPUSwapChain::destroy()
{
    if (!m_swapChain)
        return;

    m_swapChain->destroy();
    m_swapChain = nullptr;

    if (m_currentTexture && m_currentTexture->texture())
        m_currentTexture->destroy();
}

} // namespace WebCore

#endif // ENABLE(WEBGPU)
